transforms

package
v0.0.0-...-8cfed74 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2019 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Chain

func Chain(transforms ...*matrix.Matrix) *matrix.Matrix

Chain chains several transformations into one

func RotationX

func RotationX(r float64) *matrix.Matrix

RotationX returns a matrix that represents a rotation by r radians around the X axis

func RotationY

func RotationY(r float64) *matrix.Matrix

RotationY returns a matrix that represents a rotation by r radians around the Y axis

func RotationZ

func RotationZ(r float64) *matrix.Matrix

RotationZ returns a matrix that represents a rotation by r radians around the Z axis

func Scaling

func Scaling(x, y, z float64) *matrix.Matrix

Scaling returns a matrix representing a scaling operation

func Shearing

func Shearing(Xy, Xz, Yx, Yz, Zx, Zy float64) *matrix.Matrix

Shearing returns a matrix that represents a shearing (skew) operation

func Translation

func Translation(x, y, z float64) *matrix.Matrix

Translation returns a matrix representing a translation operation

func ViewTransform

func ViewTransform(from tuple.Tuple, to tuple.Tuple, up tuple.Tuple) *matrix.Matrix

ViewTransform returns a matrix that represents viewing vector

Types

This section is empty.

Jump to