Documentation
¶
Index ¶
- func Chain(transforms ...*matrix.Matrix) *matrix.Matrix
- func RotationX(r float64) *matrix.Matrix
- func RotationY(r float64) *matrix.Matrix
- func RotationZ(r float64) *matrix.Matrix
- func Scaling(x, y, z float64) *matrix.Matrix
- func Shearing(Xy, Xz, Yx, Yz, Zx, Zy float64) *matrix.Matrix
- func Translation(x, y, z float64) *matrix.Matrix
- func ViewTransform(from tuple.Tuple, to tuple.Tuple, up tuple.Tuple) *matrix.Matrix
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RotationX ¶
RotationX returns a matrix that represents a rotation by r radians around the X axis
func RotationY ¶
RotationY returns a matrix that represents a rotation by r radians around the Y axis
func RotationZ ¶
RotationZ returns a matrix that represents a rotation by r radians around the Z axis
func Translation ¶
Translation returns a matrix representing a translation operation
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.