Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type World ¶
World is a collection of objects and a light source
func (*World) Intersect ¶
func (w *World) Intersect(r ray.Ray) []shape.Intersection
Intersect returns the intersections of a collection of objects with a ray
func (*World) IsShadowed ¶
IsShadowed determines if a point is shadowed in a world
func (*World) ReflectedColor ¶
func (w *World) ReflectedColor(c *shape.Computation) color.Color
ReflectedColor determines the reflected color for a precomputation
Click to show internal directories.
Click to hide internal directories.